@@ -17,6 +17,7 @@
 
 package org.apache.doris.flink.source;
 
+import org.apache.flink.annotation.PublicEvolving;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.connector.source.Boundedness;
 import org.apache.flink.api.connector.source.Source;
@@ -49,6 +50,7 @@ import java.util.Collection;
 import java.util.List;
 
 /** DorisSource based on FLIP-27 which is a BOUNDED stream. */
+@PublicEvolving
 public class DorisSource<OUT>
         implements Source<OUT, DorisSourceSplit, PendingSplitsCheckpoint>,
                 ResultTypeQueryable<OUT> {
@@ -95,9 +97,12 @@ public class DorisSource<OUT>
         List<DorisSourceSplit> dorisSourceSplits = new ArrayList<>();
         List<PartitionDefinition> partitions =
                 RestService.findPartitions(options, readOptions, LOG);
-        partitions.forEach(m -> dorisSourceSplits.add(new DorisSourceSplit(m)));
+        for (int index = 0; index < partitions.size(); index++) {
+            PartitionDefinition partitionDef = partitions.get(index);
+            String splitId = partitionDef.getBeAddress() + "_" + index;
+            dorisSourceSplits.add(new DorisSourceSplit(splitId, partitionDef));
+        }
         DorisSplitAssigner splitAssigner = new SimpleSplitAssigner(dorisSourceSplits);
-
         return new DorisSourceEnumerator(context, splitAssigner);
     }
 
@@ -106,6 +111,7 @@ public class DorisSource<OUT>
             SplitEnumeratorContext<DorisSourceSplit> context, PendingSplitsCheckpoint checkpoint)
             throws Exception {
         Collection<DorisSourceSplit> splits = checkpoint.getSplits();
+        LOG.info("Restore splits from checkpoint, size {}, splits {}", splits.size(), splits);
         DorisSplitAssigner splitAssigner = new SimpleSplitAssigner(splits);
         return new DorisSourceEnumerator(context, splitAssigner);
     }
@@ -147,27 +153,51 @@ public class DorisSource<OUT>
             boundedness = Boundedness.BOUNDED;
         }
 
+        /**
+         * Sets the DorisOptions for the DorisSource.
+         *
+         * @param options the common options of the doris cluster.
+         * @return this DorisSourceBuilder.
+         */
         public DorisSourceBuilder<OUT> setDorisOptions(DorisOptions options) {
             this.options = options;
             return this;
         }
 
+        /**
+         * Sets the DorisReadOptions for the DorisSource.
+         *
+         * @param readOptions the read options of the DorisSource.
+         * @return this DorisSourceBuilder.
+         */
         public DorisSourceBuilder<OUT> setDorisReadOptions(DorisReadOptions readOptions) {
             this.readOptions = readOptions;
             return this;
         }
 
+        /** Sets the Boundedness for the DorisSource, Currently only BOUNDED is supported. */
         public DorisSourceBuilder<OUT> setBoundedness(Boundedness boundedness) {
             this.boundedness = boundedness;
             return this;
         }
 
+        /**
+         * Sets the {@link DorisDeserializationSchema deserializer} of the Record for DorisSource.
+         *
+         * @param deserializer the deserializer for Doris Record.
+         * @return this DorisSourceBuilder.
+         */
         public DorisSourceBuilder<OUT> setDeserializer(
                 DorisDeserializationSchema<OUT> deserializer) {
             this.deserializer = deserializer;
             return this;
         }
 
+        /**
+         * Build the {@link DorisSource}.
+         *
+         * @return a DorisSource with the settings made for this builder.
+         */
         public DorisSource<OUT> build() {
             if (readOptions == null) {
                 readOptions = DorisReadOptions.builder().build();
